{ inputs, pkgs, ... }:

{
  home.packages = with pkgs; [
    unstable.firefoxpwa
  ];

  programs.firefox = {
    enable = true;
    nativeMessagingHosts = [ pkgs.unstable.firefoxpwa ];
    policies = {
      DisableTelemetry = true;
      DisableFirefoxStudies = true;
      EnableTrackingProtection = {
        Value = true;
        Locked = true;
        Cryptomining = true;
        Fingerprinting = true;
      };
      DisablePocket = true;
      DisableFirefoxAccounts = true;
      DisableAccounts = true;
      DontCheckDefaultBrowser = true;
      DisplayBookmarksToolbar = "never";
      ExtensionSettings = {
        "nl-NL@dictionaries.addons.mozilla.org" = {
          install_url = "https://addons.mozilla.org/firefox/downloads/latest/woordenboek-nederlands/latest.xpi";
          installation_mode = "force_installed";
        };
        "uBlock0@raymondhill.net" = {
          install_url = "https://addons.mozilla.org/firefox/downloads/latest/ublock-origin/latest.xpi";
          installation_mode = "force_installed";
        };
        "{446900e4-71c2-419f-a6a7-df9c091e268b}" = {
          install_url = "https://addons.mozilla.org/firefox/downloads/latest/bitwarden-password-manager/latest.xpi";
          installation_mode = "force_installed";
        };
        "firefoxpwa@filips.si" = {
          install_url = "https://addons.mozilla.org/firefox/downloads/latest/pwas-for-firefox/latest.xpi";
          installation_mode = "force_installed";
        };
      };
    };
    profiles.xeovalyte = {
      search.engines = {
        "Nix" = {
          urls = [{
            template = "https://mynixos.com/search";
            params = [
              { name = "q"; value = "{searchTerms}"; }
            ];
          }];

          icon = "${pkgs.nixos-icons}/share/icons/hicolor/scalable/apps/nix-snowflake.svg";
          definedAliases = [ "@nix" ];
        };

        "SearXNG" = {
          urls = [{
            template = "https:/search.xeovalyte.dev/search";
            params = [
              { name = "q"; value = "{searchTerms}"; }
            ];
          }];

          definedAliases = [ "@searxng" ];
        };

        "Startpage" = {
          urls = [{
            template = "https:/startpage.com/sp/search";
            params = [
              { name = "q"; value = "{searchTerms}"; }
            ];
          }];

          definedAliases = [ "@sp" ];
        };

        "Bing".metaData.hidden = true;
        "Google".metaData.hidden = true;
        "eBay".metaData.hidden = true;
      };
      search.force = true;
      search.default = "SearXNG";

      settings = {
        "browser.disableResetPrompt" = true;
        "browser.download.panel.shown" = true;
        "browser.download.useDownloadDir" = false;
        "browser.newtabpage.activity-stream.showSponsoredTopSites" = false;
        "browser.shell.checkDefaultBrowser" = false;
        "browser.shell.defaultBrowserCheckCount" = 1;
        "dom.security.https_only_mode" = true;
        "privacy.trackingProtection.enabled" = true;
        "browser.toolbars.bookmarks.visibility" = "never";
        "browser.translations.neverTranslateLanguages" = "nl";
        "browser.newtabpage.pinned" = [
          {
            label = "Server";
            url = "https://home.xeovalyte.dev";
          }
          {
            label = "Youtube";
            url = "https://youtube.com";
          }
          {
            label = "Schoolportaal";
            url = "https://coenecoopcollege.sharepoint.com/";
          }
        ];
        "signon.rememberSignons" = false;
      };
    };
  };
}
